@@ -2,7 +2,6 @@ from __future__ import annotations
 
 import typing
 from itertools import chain
-from typing import Any
 from typing import Iterable
 from typing import Optional
 from typing import Tuple
@@ -12,6 +11,8 @@ from typing import Union
 from functional_predicates.base import Base
 from functional_predicates.misc import sentinel
 from functional_predicates.predicate import Predicate
+from functional_predicates.predicates.builtin import All
+from functional_predicates.predicates.builtin import Any
 from functional_predicates.predicates.builtin import Callable
 from functional_predicates.predicates.builtin import HasAttr
 from functional_predicates.predicates.builtin import IsInstance
@@ -30,7 +31,10 @@ from functional_predicates.predicates.operator import Truth
 
 class Checker(Base):
     def __init__(
-        self: Checker, *, value: Any = sentinel, predicates: Optional[Iterable[Predicate]] = None,
+        self: Checker,
+        *,
+        value: typing.Any = sentinel,
+        predicates: Optional[Iterable[Predicate]] = None,
     ) -> None:
         super().__init__(value=value)
         if predicates is None:
@@ -40,6 +44,12 @@ class Checker(Base):
 
     # builtin
 
+    def all(self: Checker) -> Checker:  # noqa: A003
+        return self._append(All)
+
+    def any(self: Checker) -> Checker:  # noqa: A003
+        return self._append(Any)
+
     def callable(self: Checker) -> Checker:  # noqa: A003
         return self._append(Callable)
 
@@ -51,22 +61,22 @@ class Checker(Base):
 
     # operator
 
-    def lt(self: Checker, x: Any) -> Checker:
+    def lt(self: Checker, x: typing.Any) -> Checker:
         return self._append(LT, x)
 
-    def le(self: Checker, x: Any) -> Checker:
+    def le(self: Checker, x: typing.Any) -> Checker:
         return self._append(LE, x)
 
-    def eq(self: Checker, x: Any) -> Checker:
+    def eq(self: Checker, x: typing.Any) -> Checker:
         return self._append(Eq, x)
 
-    def ne(self: Checker, x: Any) -> Checker:
+    def ne(self: Checker, x: typing.Any) -> Checker:
         return self._append(NE, x)
 
-    def ge(self: Checker, x: Any) -> Checker:
+    def ge(self: Checker, x: typing.Any) -> Checker:
         return self._append(GE, x)
 
-    def gt(self: Checker, x: Any) -> Checker:
+    def gt(self: Checker, x: typing.Any) -> Checker:
         return self._append(GT, x)
 
     def not_(self: Checker) -> Checker:
@@ -75,19 +85,22 @@ class Checker(Base):
     def truth(self: Checker) -> Checker:
         return self._append(Truth)
 
-    def is_(self: Checker, x: Any) -> Checker:
+    def is_(self: Checker, x: typing.Any) -> Checker:
         return self._append(Is_, x)
 
-    def is_not(self: Checker, x: Any) -> Checker:
+    def is_not(self: Checker, x: typing.Any) -> Checker:
         return self._append(IsNot, x)
 
-    def contains(self: Checker, x: Any) -> Checker:
+    def contains(self: Checker, x: typing.Any) -> Checker:
         return self._append(Contains, x)
 
     # private
 
     def _append(
-        self: Checker, cls: typing.Callable[..., Predicate], *args: Any, **kwargs: Any,
+        self: Checker,
+        cls: typing.Callable[..., Predicate],
+        *args: typing.Any,
+        **kwargs: typing.Any,
     ) -> Checker:
         return type(self)(
             value=self.value,
@@ -97,7 +110,7 @@ class Checker(Base):
     def _bool(self: Checker) -> bool:
         return all(self.predicates)
 
-    def _call(self: Checker, value: Any) -> Checker:
+    def _call(self: Checker, value: typing.Any) -> Checker:
         return type(self)(
             value=value, predicates=[predicate(value=value) for predicate in self.predicates],
         )
