@@ -9,6 +9,24 @@ from functional_predicates.check import Checker
 from functional_predicates.misc import red
 
 
+def test_all() -> None:
+    check = Check.all()
+    assert isinstance(check, Checker)
+    assert repr(check) == "all()"
+    assert check([True, True])
+    with raises(AssertionError, match=escape(red("all([True, False])"))):
+        assert check([True, False])
+
+
+def test_any() -> None:
+    check = Check.any()
+    assert isinstance(check, Checker)
+    assert repr(check) == "any()"
+    assert check([True, False])
+    with raises(AssertionError, match=escape(red("any([False, False])"))):
+        assert check([False, False])
+
+
 def test_callable() -> None:
     check = Check.callable()
     assert isinstance(check, Checker)
